@@ -132,7 +132,7 @@ class GaussianEnsemble(_Ensemble):
         # n by n matrix of random Gaussians
         mtx = np.random.randn(self.n,self.n)
         # symmetrize matrix
-        self.matrix = (mtx + mtx.transpose())/2
+        self.matrix = (mtx + mtx.transpose())/np.sqrt(2)
         return self.matrix
 
     def _sample_gue(self):
@@ -140,7 +140,7 @@ class GaussianEnsemble(_Ensemble):
         # n by n random complex matrix
         mtx = np.random.randn(size,size) + 1j*np.random.randn(size,size)
         # hermitian matrix
-        self.matrix = (mtx + mtx.transpose().conj())/2
+        self.matrix = (mtx + mtx.transpose().conj())/np.sqrt(2)
         return self.matrix
 
     def _sample_gse(self):
@@ -155,7 +155,7 @@ class GaussianEnsemble(_Ensemble):
                        [-np.conjugate(y_mtx), np.conjugate(x_mtx)]
                         ])
         # hermitian matrix
-        self.matrix = (mtx + mtx.transpose())/2
+        self.matrix = (mtx + mtx.transpose().conj())/np.sqrt(2)
         return self.matrix
 
     def sample_tridiagonal(self):
@@ -201,14 +201,15 @@ class GaussianEnsemble(_Ensemble):
         """
         return np.linalg.eigvalsh(self.matrix)
 
-    def eigval_hist(self, bins, interval=None, density=False, norm_const=None):
+    def eigval_hist(self, bins, interval=None, density=False, norm_const=None, avoid_img=False):
         if self.use_tridiagonal:
             if norm_const:
                 return tridiag_eigval_hist(self.matrix*norm_const, bins=bins,
                                            interval=interval, density=density)
             return tridiag_eigval_hist(self.matrix, bins=bins, interval=interval, density=density)
 
-        return super().eigval_hist(bins, interval, density, norm_const)
+        return super().eigval_hist(bins, interval=interval, density=density,
+                                   norm_const=norm_const, avoid_img=avoid_img)
 
     def plot_eigval_hist(self, bins, interval=None, density=False, norm_const=None, fig_path=None):
         """Calculates and plots the histogram of the matrix eigenvalues
@@ -246,11 +247,10 @@ class GaussianEnsemble(_Ensemble):
                 Journal of Mathematical Physics. 43.11 (2002): 5830-5847.
 
         """
-        # pylint: disable=too-many-arguments
-        if norm_const is None:
-            norm_const = 1/np.sqrt(self.n/2)
-
         if self.use_tridiagonal:
+            # pylint: disable=too-many-arguments
+            if norm_const is None:
+                norm_const = 1/np.sqrt(self.n/2)
             observed, bins = tridiag_eigval_hist(self.matrix*norm_const, bins=bins,
                                                  interval=interval, density=density)
             width = bins[1]-bins[0]
@@ -267,7 +267,11 @@ class GaussianEnsemble(_Ensemble):
                 plt.show()
 
         else:
-            super().plot_eigval_hist(bins, interval, density, norm_const, fig_path)
+            # pylint: disable=too-many-arguments
+            if norm_const is None:
+                norm_const = 1/np.sqrt(self.n)
+            super().plot_eigval_hist(bins, interval=interval, density=density,
+                                     norm_const=norm_const, fig_path=fig_path)
 
     def eigval_pdf(self):
         '''Calculates joint eigenvalue pdf.
