@@ -60,6 +60,9 @@ class ManovaEnsemble(_Ensemble):
             that generates the matrix of the corresponding ensemble.
 
     References:
+        Erdos, L. and Farrell, B.
+            "Local Eigenvalue Density for General MANOVA Matrices".
+            Journal of Statistical Physics. 152.6 (2013): 1003-1032.
         Dumitriu, I. and Edelman, A. "Matrix Models for Beta Ensembles".
             Journal of Mathematical Physics. 43.11 (2002): 5830-5847.
 
@@ -161,9 +164,9 @@ class ManovaEnsemble(_Ensemble):
         # m by n2 random complex matrix of random Gaussians
         y_mtx = np.random.randn(m_size,n2_size) + (0+1j)*np.random.randn(m_size,n2_size)
         # A1 = X * X'
-        a1_mtx = np.matmul(x_mtx, x_mtx.transpose())
+        a1_mtx = np.matmul(x_mtx, x_mtx.transpose().conj())
         # A2 = X * X' + Y * Y'
-        a2_mtx = a1_mtx + np.matmul(y_mtx, y_mtx.transpose())
+        a2_mtx = a1_mtx + np.matmul(y_mtx, y_mtx.transpose().conj())
         # A = (X * X') / (X * X' + Y * Y') = (X * X') * (X * X' + Y * Y')^(-1)
         self.matrix = np.matmul(a1_mtx, np.linalg.inv(a2_mtx))
         return self.matrix
@@ -191,9 +194,9 @@ class ManovaEnsemble(_Ensemble):
                          [-np.conjugate(y2_mtx), np.conjugate(y1_mtx)]
                         ])
         # A1 = X * X'
-        a1_mtx = np.matmul(x_mtx, x_mtx.transpose())
+        a1_mtx = np.matmul(x_mtx, x_mtx.transpose().conj())
         # A2 = X * X' + Y * Y'
-        a2_mtx = a1_mtx + np.matmul(y_mtx, y_mtx.transpose())
+        a2_mtx = a1_mtx + np.matmul(y_mtx, y_mtx.transpose().conj())
         # A = (X * X') / (X * X' + Y * Y') = (X * X') * (X * X' + Y * Y')^(-1)
         self.matrix = np.matmul(a1_mtx, np.linalg.inv(a2_mtx))
         return self.matrix
@@ -214,9 +217,6 @@ class ManovaEnsemble(_Ensemble):
         """Calculates and plots the histogram of the matrix eigenvalues
 
         Calculates and plots the histogram of the current sampled matrix eigenvalues.
-        It is important to underline that this function works with real and complex
-        eigenvalues: if the matrix eigenvalues are complex, they are plotted in the
-        complex plane next to a heap map to study eigenvalue density.
 
         Args:
             bins (int or sequence): If bins is an integer, it defines the number of
@@ -238,56 +238,17 @@ class ManovaEnsemble(_Ensemble):
                 provided, the plot is shown are the end of the routine.
 
         References:
+            Erdos, L. and Farrell, B.
+                "Local Eigenvalue Density for General MANOVA Matrices".
+                Journal of Statistical Physics. 152.6 (2013): 1003-1032.
             Dumitriu, I. and Edelman, A.
                 "Matrix Models for Beta Ensembles".
                 Journal of Mathematical Physics. 43.11 (2002): 5830-5847.
 
         """
         # pylint: disable=too-many-arguments
-        # pylint: disable=too-many-locals
-        if self.beta == 1:
-            return super().plot_eigval_hist(bins, interval, density, norm_const, fig_path)
-
-        if (interval is not None) and not isinstance(interval, tuple):
-            raise ValueError("interval argument must be a tuple (or None)")
-
-        eigvals = self.eigvals()
-        xvals = eigvals.real
-        yvals = eigvals.imag
-
-        if interval is None:
-            rang = ((xvals.min(), xvals.max()), (yvals.min(), yvals.max()))
-            extent = [xvals.min(), xvals.max(), yvals.min(), yvals.max()]
-        else:
-            rang = (interval, interval)
-            extent = [interval[0], interval[1], interval[0], interval[1]]
-
-        fig, axes = plt.subplots(nrows=1, ncols=2)
-        fig.set_figheight(5)
-        fig.set_figwidth(13)
-        fig.subplots_adjust(hspace=.5)
-
-        axes[0].set_xlim(rang[0][0], rang[0][1])
-        axes[0].set_ylim(rang[1][0], rang[1][1])
-        axes[0].plot(xvals, yvals, 'o')
-        axes[0].set_title('Eigenvalue plot')
-        axes[0].set_xlabel('real')
-        axes[0].set_ylabel('imaginary')
-
-        h2d,_,_,img = axes[1].hist2d(xvals, yvals, range=rang,
-                                   cmap=plt.cm.get_cmap('nipy_spectral'))
-        fig.colorbar(img, ax=axes[1])
-        axes[1].cla()
-        axes[1].imshow(h2d.transpose(), origin='lower', interpolation="bilinear", extent=extent)
-        axes[1].set_title('Heatmap eigenvalue plot')
-        axes[1].set_xlabel('real')
-        axes[1].set_ylabel('imaginary')
-
-        # Saving plot or showing it
-        if fig_path:
-            plt.savefig(fig_path, dpi=1200)
-        else:
-            plt.show()
+        return super().plot_eigval_hist(bins, interval, density,
+                                        norm_const=norm_const, avoid_img=True, fig_path=fig_path)
 
     def eigval_pdf(self):
         '''Calculates joint eigenvalue pdf.
