@@ -222,8 +222,14 @@ def tracy_widom_law(ensemble='goe', n_size=100, times=1000, bins=100, interval=N
         eigvals = np.append(eigvals, vals.max())
         ens.sample()
 
-    # Wigner/Tracy-Widom eigenvalue normalization constant
-    eigvals = eigvals/np.sqrt(n_size/2)
+    # Tracy-Widom eigenvalue distr. normalization constant
+    eigval_scale = 1
+    if ensemble == 'gue':
+        eigval_scale = 1/np.sqrt(2)
+    if ensemble == 'gse':
+        eigval_scale = 1/np.sqrt(2)
+        n_size *= 2
+    eigvals = (n_size**(1/6)) * (eigval_scale*eigvals - (2*np.sqrt(n_size)))
 
     if interval is None:
         xmin=eigvals.min()
