@@ -150,7 +150,7 @@ class WishartEnsemble(_Ensemble):
         # p by n random complex matrix of random Gaussians
         mtx = np.random.randn(p_size,n_size) + (0+1j)*np.random.randn(p_size,n_size)
         # hermitian matrix
-        self.matrix = np.matmul(mtx, mtx.transpose())
+        self.matrix = np.matmul(mtx, mtx.transpose().conj())
         return self.matrix
 
     def _sample_wqe(self):
@@ -166,7 +166,7 @@ class WishartEnsemble(_Ensemble):
                         [-np.conjugate(y_mtx), np.conjugate(x_mtx)]
                     ])
         # hermitian matrix
-        self.matrix = np.matmul(mtx, mtx.transpose())
+        self.matrix = np.matmul(mtx, mtx.transpose().conj())
         return self.matrix
 
     def sample_tridiagonal(self):
@@ -217,14 +217,14 @@ class WishartEnsemble(_Ensemble):
         """
         return np.linalg.eigvalsh(self.matrix)
 
-    def eigval_hist(self, bins, interval=None, density=False, norm_const=None):
+    def eigval_hist(self, bins, interval=None, density=False, norm_const=None, avoid_img=False):
         if self.use_tridiagonal:
             if norm_const:
                 return tridiag_eigval_hist(self.matrix*norm_const, bins=bins,
                                            interval=interval, density=density)
             return tridiag_eigval_hist(self.matrix, bins=bins, interval=interval, density=density)
 
-        return super().eigval_hist(bins, interval, density, norm_const)
+        return super().eigval_hist(bins, interval, density, norm_const, avoid_img=avoid_img)
 
     def plot_eigval_hist(self, bins, interval=None, density=False, norm_const=None, fig_path=None):
         """Calculates and plots the histogram of the matrix eigenvalues
